@@ -12,7 +12,10 @@ def get_credentials(api_key, api_schema, db_schema):
         return None
 
 
-def get(api_key, api_schema=api.prod, db_schema=None,  buffered=True, dictionary=False):
+def get(api_key, api_schema=None, db_schema=None,  buffered=True, dictionary=False):
+    if not api_schema:
+        api_schema = api.prod
+
     credentials = get_credentials(api_key=api_key, api_schema=api_schema, db_schema=db_schema)
     if not credentials:
         return None, None
